@@ -39,6 +39,12 @@ public:
 	std::stringstream buffer;
 	unsigned long streamSize;
 	uint8_t *buf;
+	uint8_t *readBuffer;
+	unsigned long readBufferLength;
+	unsigned long readBufferPos;
+private:
+	WPSFileStreamPrivate(const WPSFileStreamPrivate&);
+	WPSFileStreamPrivate& operator=(const WPSFileStreamPrivate&);
 };
 
 class WPSMemoryStreamPrivate
@@ -55,7 +61,10 @@ WPSFileStreamPrivate::WPSFileStreamPrivate() :
 	file(),
 	buffer(std::ios::binary | std::ios::in | std::ios::out),
 	streamSize(0),
-	buf(0)
+	buf(0),
+	readBuffer(0),
+	readBufferLength(0),
+	readBufferPos(0)
 {	
 }
 
@@ -63,6 +72,8 @@ WPSFileStreamPrivate::~WPSFileStreamPrivate()
 {
 	if (buf)
 		delete [] buf;
+	if (readBuffer)
+		delete [] readBuffer;
 }
 
 WPSMemoryStreamPrivate::WPSMemoryStreamPrivate(const std::string str) :
@@ -78,15 +89,17 @@ WPSMemoryStreamPrivate::~WPSMemoryStreamPrivate()
 		delete [] buf;
 }
 
-WPSFileStream::WPSFileStream(const char* filename)
+WPSFileStream::WPSFileStream(const char* filename) :
+	d(new WPSFileStreamPrivate)
 {
-	d = new WPSFileStreamPrivate;
-	
 	d->file.open( filename, std::ios::binary | std::ios::in );
 	d->file.seekg( 0, std::ios::end );
 	d->streamSize = (d->file.good() ? (unsigned long)d->file.tellg() : (unsigned long)-1L);
 	if (d->streamSize == (unsigned long)-1) // tellg() returned ERROR
 		d->streamSize = 0;
+	 // preventing possible unsigned/signed issues later by truncating the file
+	if (d->streamSize > (std::numeric_limits<unsigned long>::max)() / 2)
+		d->streamSize = (std::numeric_limits<unsigned long>::max)() / 2;
 	d->file.seekg( 0, std::ios::beg );
 }
 
@@ -95,66 +108,106 @@ WPSFileStream::~WPSFileStream()
 	delete d;
 }
 
+#define BUFFER_MAX 65536
+
 const uint8_t *WPSFileStream::read(size_t numBytes, size_t &numBytesRead)
 {
 	numBytesRead = 0;
 	
-	if (0 == numBytes)
+	if (numBytes == 0 || /* atEOS() || */ numBytes > (std::numeric_limits<unsigned long>::max)()/2
+		|| !d->file.good())
 		return 0;
 
-	if (numBytes < 0 || atEOS() || numBytes > (std::numeric_limits<unsigned long>::max)()/2)
-		return 0;
+	// can we read from the buffer?
+	if (d->readBuffer && (d->readBufferPos + numBytes > d->readBufferPos)
+		&& (d->readBufferPos + numBytes <= d->readBufferLength))
+	{
+		const uint8_t *pTmp = d->readBuffer + d->readBufferPos;
+		d->readBufferPos += numBytes;
+		numBytesRead = numBytes;
+		return pTmp;
+	}
 
-	unsigned long curpos = d->file.tellg();
+	// hmm, we cannot: go back by the bytes we read ahead && invalidate the buffer
+	if (d->readBuffer)
+	{
+		d->file.seekg((unsigned long)d->file.tellg() - d->readBufferLength, std::ios::beg);
+		d->file.seekg(d->readBufferPos, std::ios::cur);
+		delete [] d->readBuffer;
+		d->readBuffer = 0; d->readBufferPos = 0; d->readBufferLength = 0;
+	}
+	
+	unsigned long curpos = tell();
 	if (curpos == (unsigned long)-1)  // tellg() returned ERROR
 		return 0;
 
 	if ( (curpos + numBytes < curpos) /*overflow*/ ||
-		(curpos + numBytes > d->streamSize) ) /*reading more than available*/
+		(curpos + numBytes >= d->streamSize) ) /*reading more than available*/
 	{
 		numBytes = d->streamSize - curpos;
 	}
 
-	if (d->buf)
-		delete [] d->buf;
-	d->buf = new uint8_t[numBytes];
-
-	if(d->file.good())
+	if (numBytes < BUFFER_MAX)
 	{
-		d->file.read((char *)(d->buf), numBytes); 
-		numBytesRead = (long)d->file.tellg() - curpos;
+		if (BUFFER_MAX < d->streamSize - curpos)
+			d->readBufferLength = BUFFER_MAX;
+		else /* BUFFER_MAX >= d->streamSize - curpos */
+			d->readBufferLength = d->streamSize - curpos;
 	}
+	else
+		d->readBufferLength = numBytes;
 	
-	return d->buf;
+	d->file.seekg(d->readBufferLength, std::ios::cur);
+	d->file.seekg(curpos, std::ios::beg);
+	
+	d->readBuffer = new uint8_t[d->readBufferLength];
+	d->file.read((char *)(d->readBuffer), d->readBufferLength);
+	
+	if (!d->file.good())
+		d->file.clear();
+	d->readBufferPos = 0;
+	if (d->readBufferLength == 0)
+		return 0;
+
+	numBytesRead = numBytes;
+		
+	d->readBufferPos += numBytesRead;
+	return const_cast<const uint8_t*>( d->readBuffer );
 }
 
 long WPSFileStream::tell()
 {
-	return d->file.good() ? (long)d->file.tellg() : -1L;
+	return d->file.good() ? (long)((long)d->file.tellg() - d->readBufferLength + d->readBufferPos) : -1L;
 }
 
 int WPSFileStream::seek(long offset, WPX_SEEK_TYPE seekType)
 {
-	if (seekType == WPX_SEEK_SET)
-	{
-		if (offset < 0)
-			offset = 0;
-		if (offset > d->streamSize)
-			offset = d->streamSize;
-	}
-
 	if (seekType == WPX_SEEK_CUR)
-	{
-		if (tell() + offset < 0)
-			offset = -tell();
-		if (tell() + offset > d->streamSize)
-			offset = d->streamSize - tell();
-	}
+		offset += tell();
 
+	if (offset < 0)
+		offset = 0;
+	if (offset > (long)d->streamSize)
+		offset = (long)d->streamSize;
+	
+	if (d->file.good() && offset < d->file.tellg() && (unsigned long)offset >= (unsigned long)d->file.tellg() - d->readBufferLength)
+	{
+		d->readBufferPos = offset + d->readBufferLength - d->file.tellg();
+		return 0;
+	}
+	
+	if (d->readBuffer) // seeking outside of the buffer, so invalidate the buffer
+	{
+		d->file.seekg((unsigned long)d->file.tellg() - d->readBufferLength, std::ios::beg);
+		d->file.seekg(d->readBufferPos, std::ios::cur);
+		delete [] d->readBuffer;
+		d->readBuffer = 0; d->readBufferPos = 0; d->readBufferLength = 0;
+	}
+	
 	if(d->file.good())
 	{
-		d->file.seekg(offset, ((seekType == WPX_SEEK_SET) ? std::ios::beg : std::ios::cur));
-		return (int) ((long)d->file.tellg() == -1);
+		d->file.seekg(offset, std::ios::beg);
+		return (int) ((long)d->file.tellg() == -1) ;
 	}
 	else
 		return -1;
@@ -162,25 +215,38 @@ int WPSFileStream::seek(long offset, WPX_SEEK_TYPE seekType)
 
 bool WPSFileStream::atEOS()
 {
-	return (d->file.tellg() >= d->streamSize);
+	return (tell() >= (long)d->streamSize);
 }
 
 bool WPSFileStream::isOLEStream()
 {
+	if (d->readBuffer)
+	{
+		d->file.seekg((unsigned long)d->file.tellg() - d->readBufferLength, std::ios::beg);
+		d->file.seekg(d->readBufferPos, std::ios::cur);
+		delete [] d->readBuffer;
+		d->readBuffer = 0; d->readBufferPos = 0; d->readBufferLength = 0;
+	}
+	
 	if (d->buffer.str().empty())
 		d->buffer << d->file.rdbuf();
 	Storage tmpStorage( d->buffer );
-	if (tmpStorage.isOLEStream())
-	{
-		seek(0, WPX_SEEK_SET);
-		return true;
-	}
 	seek(0, WPX_SEEK_SET);
+	if (tmpStorage.isOLEStream())
+		return true;
 	return false;
 }
 
 WPXInputStream* WPSFileStream::getDocumentOLEStream(const char * name)
 {
+	if (d->readBuffer)
+	{
+		d->file.seekg((unsigned long)d->file.tellg() - d->readBufferLength, std::ios::beg);
+		d->file.seekg(d->readBufferPos, std::ios::cur);
+		delete [] d->readBuffer;
+		d->readBuffer = 0; d->readBufferPos = 0; d->readBufferLength = 0;
+	}
+	
 	if (d->buffer.str().empty())
 		d->buffer << d->file.rdbuf();
 	Storage *tmpStorage = new Storage( d->buffer );
